==> faker-file-0.2.tar.gz: faker-file-0.2/src/faker_file/providers/pptx_file.py <==
import os
from typing import Optional

from faker.providers import BaseProvider
from pptx import Presentation

from ..base import DEFAULT_REL_PATH, FileMixin, StringValue
from ..constants import DEFAULT_TEXT_MAX_NB_CHARS
from ..content_generators import BaseContentGenerator
from ..helpers import wrap_text

__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
__copyright__ = "2022 Artur Barseghyan"
__license__ = "MIT"
__all__ = ("PptxFileProvider",)


class PptxFileProvider(BaseProvider, FileMixin):
    """PPTX file provider.

        Usage example:

        from faker_file.providers.pptx_file import PptxFileProvider

        file = PptxFileProvider(None).pptx_file()

    Usage example with options:

        from faker_file.providers.pptx_file import PptxFileProvider

        file = PptxFileProvider(None).pptx_file(
            max_nb_chars=100_000,
            wrap_chars_after=80,
            prefix="zzz",
        )
    """

    extension: str = "pptx"

    def pptx_file(
        self,
        max_nb_chars: int = DEFAULT_TEXT_MAX_NB_CHARS,
        root_path: str = None,
        rel_path: str = DEFAULT_REL_PATH,
        wrap_chars_after: Optional[int] = None,
        prefix: Optional[str] = None,
        content_generator: Optional[BaseContentGenerator] = None,
        content: Optional[str] = None,
        **kwargs,
    ) -> StringValue:
        """Generate a file with random text.

        :param max_nb_chars: Max number of chars for the content.
        :param root_path: Path of your files root directory (in case of Django
            it would be `settings.MEDIA_ROOT`).
        :param rel_path: Relative path (from root directory).
        :param wrap_chars_after: If given, the output string would be separated
             by line breaks after the given position.
        :param prefix: File name prefix.
        :param content_generator: Content generator.
        :param content: File content. If given, used as is.
        :return: Relative path (from root directory) of the generated file.
        """
        # Generic
        file_name = self._generate_filename(
            root_path=root_path,
            rel_path=rel_path,
            prefix=prefix,
        )
        data = {}

        # Specific
        if content is not None:
            if wrap_chars_after:
                content = wrap_text(content, wrap_chars_after)
        else:
            content = self._generate_content(
                max_nb_chars,
                wrap_chars_after=wrap_chars_after,
                content_generator=content_generator,
            )
        presentation = Presentation()
        # Make a blank slide with a text box with random text
        slide = presentation.slides.add_slide(presentation.slide_layouts[6])
        text_box = slide.shapes.add_textbox(0, 0, 1, 1)
        text_box.text = content
        presentation.save(file_name)

        # Generic
        file_name = StringValue(os.path.relpath(file_name, root_path))
        if data:
            file_name.data = data
        return file_name

==> faker-file-0.5.tar.gz: faker-file-0.5/src/faker_file/providers/pptx_file.py <==
import os
from typing import Optional

from faker.providers import BaseProvider
from pptx import Presentation

from ..base import DEFAULT_REL_PATH, FileMixin, StringValue
from ..constants import DEFAULT_TEXT_MAX_NB_CHARS

__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
__copyright__ = "2022 Artur Barseghyan"
__license__ = "MIT"
__all__ = ("PptxFileProvider",)


class PptxFileProvider(BaseProvider, FileMixin):
    """PPTX file provider.

        Usage example:

        from faker_file.providers.pptx_file import PptxFileProvider

        file = PptxFileProvider(None).pptx_file()

    Usage example with options:

        from faker_file.providers.pptx_file import PptxFileProvider

        file = PptxFileProvider(None).pptx_file(
            prefix="zzz",
            max_nb_chars=100_000,
            wrap_chars_after=80,
        )
    """

    extension: str = "pptx"

    def pptx_file(
        self: "PptxFileProvider",
        root_path: str = None,
        rel_path: str = DEFAULT_REL_PATH,
        prefix: Optional[str] = None,
        max_nb_chars: int = DEFAULT_TEXT_MAX_NB_CHARS,
        wrap_chars_after: Optional[int] = None,
        content: Optional[str] = None,
        **kwargs,
    ) -> StringValue:
        """Generate a file with random text.

        :param root_path: Path of your files root directory (in case of Django
            it would be `settings.MEDIA_ROOT`).
        :param rel_path: Relative path (from root directory).
        :param prefix: File name prefix.
        :param max_nb_chars: Max number of chars for the content.
        :param wrap_chars_after: If given, the output string would be separated
             by line breaks after the given position.
        :param content: File content. Might contain dynamic elements, which
            are then replaced by correspondent fixtures.
        :return: Relative path (from root directory) of the generated file.
        """
        # Generic
        file_name = self._generate_filename(
            root_path=root_path,
            rel_path=rel_path,
            prefix=prefix,
        )

        content = self._generate_text_content(
            max_nb_chars=max_nb_chars,
            wrap_chars_after=wrap_chars_after,
            content=content,
        )

        presentation = Presentation()
        # Make a blank slide with a text box with random text
        slide = presentation.slides.add_slide(presentation.slide_layouts[6])
        text_box = slide.shapes.add_textbox(0, 0, 1, 1)
        text_box.text = content
        presentation.save(file_name)

        # Generic
        file_name = StringValue(os.path.relpath(file_name, root_path))
        file_name.data = {"content": content}
        return file_name
